Module: Amatch::StringMethods

Included in:
String
Defined in:
ext/amatch_ext.c

Instance Method Summary collapse

Instance Method Details

#hamming_similar(strings) ⇒ Object

If called on a String, this string is used as a Amatch::Hamming#pattern to match against strings. It returns a Hamming distance metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings. The returned results is either a Float or an Array of Floats respectively.



1218
1219
1220
1221
1222
# File 'ext/amatch_ext.c', line 1218

static VALUE rb_str_hamming_similar(VALUE self, VALUE strings)
{
    VALUE amatch = rb_Hamming_new(rb_cHamming, self);
    return rb_Hamming_similar(amatch, strings);
}

#jaro_similar(strings) ⇒ Object

If called on a String, this string is used as a Amatch::Jaro#pattern to match against strings. It returns a Jaro metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings. The returned results is either a Float or an Array of Floats respectively.



1446
1447
1448
1449
1450
# File 'ext/amatch_ext.c', line 1446

static VALUE rb_str_jaro_similar(VALUE self, VALUE strings)
{
    VALUE amatch = rb_Jaro_new(rb_cJaro, self);
    return rb_Jaro_match(amatch, strings);
}

#jarowinkler_similar(strings) ⇒ Object

If called on a String, this string is used as a Amatch::JaroWinkler#pattern to match against strings. It returns a Jaro-Winkler metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings. The returned results are either a Float or an Array of Floats respectively.



1545
1546
1547
1548
1549
# File 'ext/amatch_ext.c', line 1545

static VALUE rb_str_jarowinkler_similar(VALUE self, VALUE strings)
{
    VALUE amatch = rb_JaroWinkler_new(rb_cJaro, self);
    return rb_JaroWinkler_match(amatch, strings);
}

#levenshtein_similar(strings) ⇒ Object

If called on a String, this string is used as a Amatch::Levenshtein#pattern to match against strings. It returns a Levenshtein distance metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings. The returned results is either a Float or an Array of Floats respectively.



844
845
846
847
848
# File 'ext/amatch_ext.c', line 844

static VALUE rb_str_levenshtein_similar(VALUE self, VALUE strings)
{
    VALUE amatch = rb_Levenshtein_new(rb_cLevenshtein, self);
    return rb_Levenshtein_similar(amatch, strings);
}

#longest_subsequence_similar(strings) ⇒ Object

If called on a String, this string is used as a Amatch::LongestSubsequence#pattern to match against strings. It returns a longest subsequence distance metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings. The returned results is either a Float or an Array of Floats respectively.



1294
1295
1296
1297
1298
# File 'ext/amatch_ext.c', line 1294

static VALUE rb_str_longest_subsequence_similar(VALUE self, VALUE strings)
{                                                                            
    VALUE amatch = rb_LongestSubsequence_new(rb_cLongestSubsequence, self);
    return rb_LongestSubsequence_similar(amatch, strings);
}

#longest_substring_similar(strings) ⇒ Object

If called on a String, this string is used as a Amatch::LongestSubstring#pattern to match against strings. It returns a longest substring distance metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings. The returned results is either a Float or an Array of Floats respectively.



1372
1373
1374
1375
1376
# File 'ext/amatch_ext.c', line 1372

static VALUE rb_str_longest_substring_similar(VALUE self, VALUE strings)
{                                                                            
    VALUE amatch = rb_LongestSubstring_new(rb_cLongestSubstring, self);
    return rb_LongestSubstring_similar(amatch, strings);
}

#pair_distance_similar(strings, regexp = nil) ⇒ Object

If called on a String, this string is used as a Amatch::PairDistance#pattern to match against strings using /s+/ as the tokenizing regular expression. It returns a pair distance metric number between 0.0 for very unsimilar strings and 1.0 for an exact match. strings has to be either a String or an Array of Strings.

The returned results is either a Float or an Array of Floats respectively.



1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'ext/amatch_ext.c', line 1134

static VALUE rb_str_pair_distance_similar(int argc, VALUE *argv, VALUE self)
{
    VALUE amatch, string, regexp = Qnil;
    rb_scan_args(argc, argv, "11",  &string, &regexp);
    amatch = rb_PairDistance_new(rb_cPairDistance, self);
    if (NIL_P(regexp)) {
        return rb_PairDistance_match(1, &string, amatch);
    } else {
        VALUE *args = alloca(2);
        args[0] = string;
        args[1] = regexp;
        return rb_PairDistance_match(2, args, amatch);
    }
}